@@ -25,7 +25,7 @@
 # 
 #END_HEADER
 #
-# written by Kazuharu Arakawa <gaou@g-language.org> at
+# written by Kazuharu Arakawa <gaou@sfc.keio.ac.jp> at
 # G-language Project, Institute for Advanced Biosciences, Keio University.
 #
 
@@ -269,7 +269,7 @@ __END__
 
 =head1 AUTHOR
 
-  Kazuharu Gaou Arakawa, gaou@g-language.org
+  Kazuharu Arakawa, gaou@sfc.keio.ac.jp
 
 =head1 SEE ALSO
 
