@@ -32,6 +32,7 @@ use G::Tools::Graph;
 
 use strict;
 use Statistics::Descriptive;
+use Math::FFT;
 use SelfLoader;
 
 require Exporter;
@@ -41,6 +42,7 @@ our @ISA = qw(Exporter);
 our @EXPORT = qw(
 	     find_ori_ter
 	     gcskew
+	     gcsi
 	     cum_gcskew
 	     genomicskew
 	     gcwin
@@ -51,7 +53,6 @@ our @EXPORT = qw(
 	     set_gc3
 	     genes_from_ori
 	     rep_ori_ter
-	     view_cds
 	     dist_in_cc
 );
 
@@ -81,123 +82,6 @@ __DATA__
 #:::::::::::::::::::::::::::::::::
 
 
-=head2 view_cds
-
-  Name: view_cds   -   displays a graph of nucleotide contents around start and stop codons
-
-  Description:
-    This method creates a graph showing the average A,T,G,C contents
-    around start/stop codons. This is useful to view consensus around
-    start/stop codons and to find characteristic pattern in CDS. 
-    
-  Usage : 
-    view_cds(G instance);
-
-  Options:
-    -length    length in bases to show around start/stop codons
-               (default: 100)
-    -gap       gap shown in graph in between start/stop codon neighbors
-               (default: 3)
-    -filename  outfile name   (default: view_cds.png for graph, 
-               view_cds.csv for file)
-    -output    "f" for file, "g" for graph, "show" to display graph. 
-               (default: "show")
-
-  Author: 
-    Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
-
-  History:
-    20010906-01 initial posting
-
-=cut
-
-
-
-sub view_cds{
-    &opt_default(length=>100, filename=>"view_cds.png", 
-		  gap=>3, output=>"show", application=>"gimv");
-    my @args = opt_get(@_);
-    my $gb = opt_as_gb(shift @args);
-    my (@a, @t, @g, @c, @pos);
-    my $numcds = 0;
-    my $i = 0;
-    my $length = opt_val("length");
-    my $filename = opt_val("filename");
-    my $output = opt_val("output");
-    my $application = opt_val("application");
-
-    $filename = "view_cds.csv" if ($output eq "f" &&
-				   opt_val("filename") eq "view_cds.png");
-    my $gap = opt_val("gap");
-
-    while(defined %{$gb->{"CDS$numcds"}}){ $numcds ++ }
-
-    for ($i = 0; $i < $length * 4 + 6 + $gap; $i++){
-	$a[$i] = 0;
-	$t[$i] = 0;
-	$g[$i] = 0;
-	$c[$i] = 0;
-    }
-
-    foreach my $cds ($gb->cds()){
-	my $seq;
-	$seq  = $gb->before_startcodon($cds, $length);
-	$seq .= $gb->startcodon($cds);
-	$seq .= $gb->after_startcodon($cds, $length);
-	
-	for ($i = 0; $i < length($seq); $i ++){
-	    if     (substr($seq, $i, 1) eq 'a'){
-		$a[$i] += 100/$numcds;
-	    }elsif (substr($seq, $i, 1) eq 't'){
-		$t[$i] += 100/$numcds;
-	    }elsif (substr($seq, $i, 1) eq 'g'){
-		$g[$i] += 100/$numcds;
-	    }elsif (substr($seq, $i, 1) eq 'c'){
-		$c[$i] += 100/$numcds;
-	    }
-        }
-	
-	$seq  = $gb->before_stopcodon($cds, $length);
-	$seq .= $gb->stopcodon($cds);
-	$seq .= $gb->after_stopcodon($cds, $length);
-	
-	for ($i = 0; $i < length($seq); $i ++){
-	    if     (substr($seq, $i, 1) eq 'a'){
-		$a[$i + length($seq) + $gap] += 100/$numcds;
-	    }elsif (substr($seq, $i, 1) eq 't'){
-		$t[$i + length($seq) + $gap] += 100/$numcds;
-	    }elsif (substr($seq, $i, 1) eq 'g'){
-		$g[$i + length($seq) + $gap] += 100/$numcds;
-	    }elsif (substr($seq, $i, 1) eq 'c'){
-		$c[$i + length($seq) + $gap] += 100/$numcds;
-	    }
-	}
-    }
-    
-    for ($i = 1; $i <= $length * 4 + 6 + $gap; $i ++){
-	push(@pos, $i);
-    }
-
-    if ($output eq "g" || $output eq "show"){
-	_UniMultiGrapher(
-			 \@pos, -x => "position", -y => "percentage",
-			 \@a, -x1=>"A", \@t, -x2=>"T",
-			 \@g, -x3=>"G", \@c, -x4=>"C",
-			 -filename => $filename,
-			 -title => "Base Contents Around Start/Stop Codons"
-			 );
-	msg_gimv("graph/$filename") if($output eq "show");
-    }elsif ($output eq "f"){
-	open(OUT, '>data/' . $filename);
-	print OUT "position,A,T,G,C\n";
-	
-	for ($i = 0; $i < $length * 4 + 6 + $gap; $i ++){
-	    printf OUT "%d,%3.2f,%3.2f,%3.2f,%3.2f\n", $i + 1, 
-	    $a[$i], $t[$i], $g[$i], $c[$i];
-	}
-	close(OUT);
-    }
-}
 
 
 =head2 find_ori_ter
@@ -205,23 +89,40 @@ sub view_cds{
  Name: find_ori_ter   -   predict the replication origin and terminus in bacterial genomes
 
  Description:
-    Predicts the replicational origin and terminus in circular bacterial genomes.
+    Predicts the replicational origin and terminus in circular bacterial genomes,
+    by taking the vertices of cumulative skew graphs (GC, keto, or purine). See
+    Reference 1 for the basic idea behind thid algorithm (but also note that this
+    algorithm is different from that of Oriloc, which uses GC3 of genes). 
+
+    Terminus of replication can be more accurate by using noise-reduction 
+    filtering using Fourier spectrum of the GC skew. This low-pass filtering
+    can be applied using -filter option. See Reference 2 for details.
 
  Usage:
-    (int origin, int terminus) = find_ori_ter(G instance);
+    ($origin, $terminus) = find_ori_ter($genome);
 
  Options:
    -output    output toggle option (default: stdout)
    -purine    use purine skew for calculation (default: 0)
    -keto      use keto skew for calculation (default: 0)
+   -filter    lowpass filter strength in percent. typically 95 or 99 works best. (default: NULL)
+   -window    number of windows to use for Fast Fourier Transform. only active 
+              when -filter option is specified. value must be the power of two. (default: 4096)
+
+ References:
+   1. Frank AC, Lobry JR (2000) "Oriloc: prediction of replication boundaries in unannotated 
+      bacterial chromosomes", Bioinformatics, 16:566-567.
+   2. Arakawa K, Saito R, Tomita M (2007) "Noise-reduction filtering for accurate detection 
+      of replication termini in bacterial genomes", FEBS Letters, 581(2):253-258.
 
  Author: 
     Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
 
  History:
+   20070707-01 added -filter option
    20060711-01 added purine and keto options
    20060707-01 calculation is now based on single bp resolution rather than with windows
-              but now it is a lot more slower...
+               but now it is a lot more slower...
    20060221-01 speed up using Statistics::Descriptive
    20010905-01 options update
    20010326-01 initial posting
@@ -230,41 +131,82 @@ sub view_cds{
 
 
 sub find_ori_ter {
-    &opt_default(output=>"stdout", purine=>0, keto=>0);
+    &opt_default(output=>"stdout", purine=>0, keto=>0, window=>4096);
     my @args = opt_get(@_);
     my $gb = opt_as_gb(shift @args);
     my $seq = $gb->{SEQ};
     my $output = opt_val("output");
     my $purine = opt_val("purine");
     my $keto = opt_val("keto");
+    my $lowpass = opt_val("filter");
+    my $power = opt_val("window");
 
     &msg_send("\nfind_ori_ter:\n") if ($output eq 'stdout');
 
-    if($purine){
-	$seq =~ tr/atgcn/02021/;
-    }elsif($keto){
-	$seq =~ tr/atgcn/20021/;
-    }else{
-	$seq =~ tr/atgcn/11021/;
-    }
+    my ($max, $min);
+    if(length $lowpass){
+	my $window = int(length($gb->{SEQ}) / $power);
+	my @gcskew = gcskew($gb, -output=>"/dev/null", -window=>$window, -purine=>$purine, -keto=>$keto);
 
-    my (@data, $val, $i);
-    for($i = 0; $i <= length($seq); $i ++){
-	if(substr($seq, $i, 1) =~ /^\d$/){
-	    $val += substr($seq, $i, 1) - 1;
+	while(scalar @gcskew > $power){
+	    pop @gcskew;
 	}
-	push(@data, $val);
+
+	my $fft = new Math::FFT([@gcskew]);
+	my $coeff = $fft->rdft();
+	my $coeff2 = [@{$coeff}];
+	my $spctrm = $fft->spctrm();
+	my $j;
+	my $power2 = int($power/100);
+	$power2 ++ if ($power2 %2 == 1);
+
+	for($j = $power2 * (100 - $lowpass) - 1; $j < $power; $j ++){
+	    $coeff->[$j] = 0;
+	}
+    
+	my $orig = $fft->invrdft($coeff);
+
+	my (@cum, $tmp);
+	foreach my $value (@{$orig}){
+	    $tmp += $value;
+	    push(@cum, $tmp);
+	}
+
+	my $stat = Statistics::Descriptive::Full->new();
+	$stat->add_data(@cum);
+	my $maxi = $stat->maxdex();
+	my $mini = $stat->mindex();
+
+	$max = ($maxi + 1) * $window - int($window/2);
+	$min = ($mini + 1) * $window - int($window/2);
+    }else{
+
+	if($purine){
+	    $seq =~ tr/atgcn/02021/;
+	}elsif($keto){
+	    $seq =~ tr/atgcn/20021/;
+	}else{
+	    $seq =~ tr/atgcn/11021/;
+	}
+
+	my (@data, $val, $i);
+	for($i = 0; $i <= length($seq); $i ++){
+	    if(substr($seq, $i, 1) =~ /^\d$/){
+		$val += substr($seq, $i, 1) - 1;
+	    }
+	    push(@data, $val);
+	}
+
+	my $stat = Statistics::Descriptive::Full->new();
+	$stat->add_data(@data);
+	$max = $stat->maxdex();
+	$min = $stat->mindex();
     }
 
-    my $stat = Statistics::Descriptive::Full->new();
-    $stat->add_data(@data);
-    my $maxi = $stat->maxdex();
-    my $mini = $stat->mindex();
+    &msg_send("   Predicted Origin:   " , $max, "\n")  if ($output eq 'stdout');
+    &msg_send("   Predicted Terminus: " , $min, "\n\n") if ($output eq 'stdout');
 
-    &msg_send("   Predicted Origin:   " , $maxi, "\n")  if ($output eq 'stdout');
-    &msg_send("   Predicted Terminus: " , $mini, "\n\n") if ($output eq 'stdout');
-
-    return ($maxi, $mini);
+    return ($max, $min);
 }
 
 
@@ -277,19 +219,29 @@ sub find_ori_ter {
  Name: rep_ori_ter   -   get the positions of replication origin and terminus
 
  Description:
-    This method returns the replicational origin and terminus.
-    If not known, the origin and terminus is predicted using
-    find_ori_ter();
+    This method returns the documented replicational origin and terminus.
+    Currently positions are available in the following genomes:
+     [1] Escherichia coli K12, Bacillus subtilis, Haemophilus influenzae
+     [2] Salmonella typhi
+
+    If no documentation is available, the origin and terminus is predicted using
+    find_ori_ter().
 
  Usage: 
-    (int ori, int ter) = rep_ori_ter(G instance);
+    ($ori, $ter) = rep_ori_ter($genome);
+
+ References:
+   1. Freeman JM et al. (1998) "Patterns of Genome Organization in Bacteria", 
+      Science, 279(5358):1827a
+   2. Parkhill J et al. (2001) "Complete genome sequence of a multiple drug 
+      resistant Salmonella enterica serovar Typhi CT18", Nature, 413(6858):848-852 
 
  Options:
    none
 
-  Author: Kazuharu Gaou Arakawa
+ Author: Kazuharu Arakawa
 
-  History:
+ History:
     20011030-01 initial posting
 
 =cut
@@ -308,23 +260,15 @@ sub rep_ori_ter {
     }else{
 
 	if ($id eq 'U00096' || $id eq 'NC_000913'){
-	    #Escherichia coli K12
-	    #Freeman et al 1998
 	    $ori = 3923500 - 1; 
 	    $ter = 1588800 - 1; 
 	}elsif ($id eq 'AL009126' || $id eq 'NC_000964'){
-	    #Bacillus subtilis
-	    #Freeman et al 1998
 	    $ori = 1 - 1;
 	    $ter = 2017000 - 1;
 	}elsif ($id eq 'L42023' || $id eq 'NC_000907'){
-	    #Haemophilus influenzae
-	    #Freeman et al 1998
 	    $ori = 603000 - 1;
 	    $ter = 1518000 - 1;
 	}elsif ($id eq 'AL513382' || $id eq 'NC_003198'){
-	    #Salmonella typhi
-	    #Parkhill et al 2001
 	    $ori = 3765000 - 1;
 	    $ter = 1437000 - 1;
 	}else{
@@ -339,6 +283,12 @@ sub rep_ori_ter {
 }
 
 
+
+
+
+
+
+
 =head2 leading_strand 
 
  Name: leading_strand   -   get the sequences of leading strands
@@ -382,6 +332,108 @@ sub leading_strand {
 }
 
 
+
+
+
+=head2 gcsi
+
+  Name: gcsi   -   GC Skew Index: an index for strand-specific mutational bias
+
+  Description:
+    This program calculates the GC Skew Index (GCSI) of the given circular
+    bacterial genome. GCSI quantifies the degree of GC Skew. In other words,
+    this index represents the degree of strand-specific mutational bias in 
+    bacterial genomes, caused by replicational selection. 
+
+    GCSI is calculated by the following formula:
+        GCSI = ((SR/6000) + (dist/600))/2
+    where SR is the ratio of Fourier spectral strengths of 1Hz over the average,
+    and dist is the Euclidean distance between the vertices of cumulative GC skew.
+
+    GCSI ranges from 0 (no observable skew) to 1 (strong skew), and Archaeal genomes
+    that have multiple replication origins and therefore have no observable skew
+    mostly have GCSI below 0.05. Escherichia coli genome has values around 0.10.
+
+  Usage: 
+    $gcsi = gcsi($genome);               # scalar context
+       or
+    ($gcsi, $sr, $dist) = gcsi($genome); # array context
+
+  Options:
+   -window      number of windows. must be a power of 2. (default: 4096)
+
+  References:
+    1. Arakawa K, Tomita M (2007) "The GC skew index: a measure of genomic compositional 
+       asymmetry and the degree of replicational selection", Evolutionary Bioinformatics, in press.
+
+  Author: 
+    Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
+
+  History:
+   20070707-01 initial posting
+
+=cut
+
+
+sub gcsi{
+    opt_default(window=>4096);
+    my @args = opt_get(@_);
+    my $gb = opt_as_gb(shift @args);
+    my $power = opt_val("window");
+
+    my $window = int(length($gb->{SEQ}) / $power);
+
+    my @gcskew = gcskew($gb, -output=>"/dev/null", -window=>$window);
+    my @cumgcskew = gcskew($gb, -output=>"/dev/null", -window=>$window, -cumulative=>1);
+
+    while(scalar @gcskew > $power){
+        pop @gcskew;
+    }
+
+    my $fft = new Math::FFT([@gcskew]);
+    my $coeff = $fft->rdft();
+    my $coeff2 = [@{$coeff}];
+    my $spctrm = $fft->spctrm();
+    my @spectrum = @$spctrm;
+
+    shift @spectrum;
+    my $first = shift @spectrum;
+
+    my $stat = Statistics::Descriptive::Full->new();
+    $stat->add_data(splice(@spectrum, 0, 50));
+    my $maxi = $stat->maxdex() + 2;
+    my $max = $stat->max();
+    my $avg50 = $stat->mean();
+
+    undef $stat;
+    my $stat = Statistics::Descriptive::Full->new();
+    $stat->add_data(@spectrum);
+    my $avg = $stat->mean();
+
+    undef $stat;
+    my $stat = Statistics::Descriptive::Full->new();
+    $stat->add_data(@cumgcskew);
+    my $cmax = $stat->max();
+    my $cmin = $stat->min();
+
+    my $sr = $first/$avg;
+    my $dist = abs($cmax)+abs($cmin);
+    my $gcsi = ($sr/6000 + $dist/600)/2;
+
+    if(wantarray()){
+	return ($gcsi, $sr, $dist);
+    }else{
+	return $gcsi;
+    }
+		
+}
+
+
+
+
+
+
+
 =head2 gcskew
 
  Name: gcskew   -   calculate the GC skew of the given genome
@@ -394,6 +446,7 @@ sub leading_strand {
 
  Options:
    -window      window size to observe (default: 10000)
+   -cumulative  1 to calculate cumulative skew (default: 0)
    -at          1 when observing AT skew instead of GC skew (default: 0)
    -purine      1 when observing purine (AG/TC) skew (default: 0)
    -keto        1 when observing keto (TG/AC) skew (default: 0)
@@ -407,6 +460,7 @@ sub leading_strand {
     Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
 
  History:
+   20070707-01 added -cumulative option
    20060711-01 added purine and keto skew
    20010905-01 update with options
    20010727-01 initial posting
@@ -417,13 +471,14 @@ sub leading_strand {
 
 sub gcskew {
     &opt_default(window=>10000, at=>0, purine=>0, keto=>0, output=>"show", 
-		 application=>"gimv",filename=>"gcskew.png");
+		 filename=>"gcskew.png", -cumulative=>0);
     my @args = opt_get(@_);
     my $gb = opt_as_gb(shift @args);
     my $ref = \$gb->{SEQ};
     my $window = opt_val("window");
-    my $application = opt_val("application");
     my $output = opt_val("output");
+    my $cumulative = '';
+    $cumulative = "Cumulative " if (opt_val("cumulative"));
     my $filename = opt_val("filename");
     $filename =~ s/\.png$/\.csv/ if (opt_val("output") eq 'f');
     my $at = opt_val("at");
@@ -432,7 +487,8 @@ sub gcskew {
     my @gcskew = ();
     my @location = ();
     my $j;
-    
+    my $tmp = 0;
+
     my $i = 0;
     while(length($$ref) - ($window * $i) >= $window){
 	my ($g, $c);
@@ -455,10 +511,19 @@ sub gcskew {
 	    $c = substr($$ref, $window * $i, $window) =~ tr/c/c/;
 	}
 
-	if ($c+$g <= 0){
-	    $gcskew[$i] = 0;
+	if(length($cumulative)){
+	    if ($c+$g <= 0){
+		$tmp += 0;
+	    }else{
+		$tmp += sprintf("%.6f",($c-$g)/($c+$g));
+	    }
+	    $gcskew[$i] = $tmp;
 	}else{
-	    $gcskew[$i] = sprintf("%.6f",($c-$g)/($c+$g));
+	    if ($c+$g <= 0){
+		$gcskew[$i] = 0;
+	    }else{
+		$gcskew[$i] = sprintf("%.6f",($c-$g)/($c+$g));
+	    }
 	}
 
 	$location[$i] = $i * $window;
@@ -466,13 +531,13 @@ sub gcskew {
     }
     $i --;
 
-    my $title = "GC skew";
+    my $title = $cumulative . "GC skew";
     if ($at){
-	$title = "AT skew";
+	$title = $cumulative . "AT skew";
     }elsif($purine){
-	$title = "Purine skew";
+	$title = $cumulative . "Purine skew";
     }elsif($keto){
-	$title = "Keto skew";
+	$title = $cumulative . "Keto skew";
     }
     
     if ($output eq 'g' || $output eq 'show'){
@@ -485,6 +550,7 @@ sub gcskew {
 			 -title=>$title,
 			 -style=>"lines", -type=>"columns",
 			 );
+
 	msg_gimv("graph/" . $filename) if ($output eq 'show');
     }elsif ($output eq 'f'){
 	my $j = 0;
@@ -502,127 +568,12 @@ sub gcskew {
 }
 
 
-=head2 cum_gcskew
-
- Name: cum_gcskew   -   calculate the cumulative GC skew of the given genome
-
- Description:
-   This program calculates and graphs the cumulative GC skew. 
-
-  Usage: array @cum_gcskew = gcskew(G instance);
-
- Options:
-   -window      window size to observe (default: 10000)
-   -at          1 when observing AT skew instead of GC skew (default: 0)
-   -purine      1 when observing purine (AG/TC) skew (default: 0)
-   -keto        1 when observing keto (TG/AC) skew (default: 0)
-   -output      f for file output in directory "data", 
-                g for graph output in directory "graph",
-                show for graph output and display (default: "show")
-   -filename    output filename (default: "cum_gcskew.png" for -output=>"g",
-                                          "cum_gcskew.csv" for -output=>"f")
-   -application application to open png image (default: "gimv")
-
- Author: 
-    Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
-
- History:
-   20070429-01 minor bug fix related to output=>"f" option
-   20060711-01 added purine and keto skew
-   20010905-01 update with options
-   20010727-01 initial posting
-
-=cut
-
-
-
 sub cum_gcskew {
-    &opt_default(window=>10000, at=>0, purine=>0, keto=>0, output=>"show", 
-		 application=>"gimv", filename=>"cum_gcskew.png");
-    my @args = opt_get(@_);
-    
-    my $gb = opt_as_gb(shift @args);
-    my $ref = \$gb->{SEQ};
-    my $window = opt_val("window");
-    my $application = opt_val("application");
-    my $output = opt_val("output");
-    my $filename = opt_val("filename");
-    $filename =~ s/\.png$/\.csv/ if (opt_val("output") eq 'f');
-    my $at = opt_val("at");
-    my $purine = opt_val("purine");
-    my $keto = opt_val("keto");
-    my @gcskew = ();
-    my @location = ();
-    my $j;
-    my $tmp;
-    
-    my $i = 0;
-    while(length($$ref) - ($window * $i) >= $window){
-        my ($g, $c);
+    msg_error("WARNING: cum_gcskew is deprecated since v.1.6.13.\n" .
+	      "         This method will be removed in future releases.\n" .
+	      "         use gcskew($gb, -cumulative=>1) instead!\n\n");
 
-        if($at){
-            $g = substr($$ref, $window * $i, $window) =~ tr/a/a/;
-            $c = substr($$ref, $window * $i, $window) =~ tr/t/t/;
-        }elsif($purine){
-            $g = substr($$ref, $window * $i, $window) =~ tr/a/a/;
-            $g += substr($$ref, $window * $i, $window) =~ tr/g/g/;
-            $c = substr($$ref, $window * $i, $window) =~ tr/t/t/;
-            $c += substr($$ref, $window * $i, $window) =~ tr/c/c/;
-        }elsif($keto){
-            $g = substr($$ref, $window * $i, $window) =~ tr/t/t/;
-            $g += substr($$ref, $window * $i, $window) =~ tr/g/g/;
-            $c = substr($$ref, $window * $i, $window) =~ tr/a/a/;
-            $c += substr($$ref, $window * $i, $window) =~ tr/c/c/;
-        }else{
-            $g = substr($$ref, $window * $i, $window) =~ tr/g/g/;
-            $c = substr($$ref, $window * $i, $window) =~ tr/c/c/;
-        }
-
-	if ($c+$g <= 0){
-	    $tmp += 0;
-	}else{
-	    $tmp += sprintf("%.6f",($c-$g)/($c+$g));
-	}
-	$gcskew[$i] = $tmp;
-	$location[$i] = $i * $window;
-	$i ++;
-    }
-    $i --;
-
-    my $title = "Cumulative GC skew";
-    if ($at){
-        $title = "Cumulative AT skew";
-    }elsif($purine){
-        $title = "Cumulative Purine skew";
-    }elsif($keto){
-        $title = "Cumulative Keto skew";
-    }
-    
-    if ($output eq 'g' || $output eq 'show'){
-	mkdir ("graph", 0777);
-
-	_UniMultiGrapher(
-			 \@location,\@gcskew,
-			 -x=>"bp", -y=>$title,
-			 -filename=>$filename,
-			 -title=>$title,
-			 -style=>"lines", -type=>"columns",
-			 );
-
-	msg_gimv("graph/" . $filename) if ($output eq 'show');
-    }elsif ($output eq 'f'){
-	my $j = 0;
-	mkdir ("data", 0777);
-
-	open(OUT, ">data/" . $filename);
-	print OUT "location,$title\n";
-	for ($j = 0; $j <= $i; $j++){
-	    print OUT $location[$j], ",", $gcskew[$j], "\n";
-	}
-	close(OUT);
-    }
-    
-    return @gcskew;
+    return gcskew(@_, -cumulative=>1);
 }
 
 
@@ -640,12 +591,12 @@ sub cum_gcskew {
 
  Options:
    -divide      window number to divide into (default: 250)
-   -at          1 when observing AT skew instead of GC skew (default: 0)
+   -At          1 when observing AT skew instead of GC skew (default: 0)
    -output      f for file output in directory "data", 
                 g for graph output in directory "graph",
                 show for graph output and display (default: "show")
-   -filename    output filename (default: "cum_gcskew.png" for -output=>"g",
-                                          "cum_gcskew.csv" for -output=>"f")
+   -filename    output filename (default: "genomicskew.png" for -output=>"g",
+                                          "genomicskew.csv" for -output=>"f")
    -application application to open png image (default: "gimv")
 
  Author: 
@@ -935,7 +886,7 @@ sub gcwin  {
 
 
 
-sub query_strand {
+Sub query_strand {
     opt_default(direction=>'direct');
     my @args = opt_get(@_);
     my $gb = shift @args;
