@@ -25,7 +25,7 @@
 # 
 #END_HEADER
 #
-# written by Kazuharu Arakawa <gaou@g-language.org> at
+# written by Kazuharu Arakawa <gaou@sfc.keio.ac.jp> at
 # G-language Project, Institute for Advanced Biosciences, Keio University.
 #
 
@@ -101,7 +101,7 @@ map {$einfo{$_} = 1} qw(
    None.
 
   Author: 
-    Kazuharu Arakawa (gaou@g-language.org)
+    Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
 
   History:
    20070601-01 initial posting
@@ -166,7 +166,7 @@ sub pubmed {
    None.
 
   Author: 
-    Kazuharu Arakawa (gaou@g-language.org)
+    Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
 
   History:
    20070601-01 initial posting
