@@ -25,7 +25,7 @@
 # 
 #END_HEADER
 #
-# written by Kazuharu Arakawa <gaou@g-language.org> at
+# written by Kazuharu Arakawa <gaou@sfc.keio.ac.jp> at
 # G-language Project, Institute for Advanced Biosciences, Keio University.
 #
 
@@ -117,7 +117,7 @@ sub buildHelpDB{
    -bp        same as above, but only for BioPerl manual
 
   Author: 
-    Kazuharu Arakawa (gaou@g-language.org)
+    Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
 
   History:
    20070531-01 initial posting
@@ -148,11 +148,13 @@ sub help{
 
 	    if(lc($pdoc{$keyword}) =~ /$lckey/){
 		push(@tmp, $keyword);
+	    }elsif(length($lckey) < 1){
+		push(@tmp, $keyword);
 	    }
 	}
 	    
 	if(scalar(@tmp)){
-	    $ans = "     Found keyword \"$key\" in the following manual pages.\n\n";
+	    $ans = sprintf("     Found keyword \"%s\" in the following manual pages \(%s hits\).\n\n", $key, scalar(@tmp));
 	    
 	    foreach my $entry (@tmp){
 		my $tmp = $pdoc{$entry};
